@@ -17,7 +17,7 @@ var searchData=
   ['textinputtarget_14',['TextInputTarget',['../classTextInputTarget.html',1,'']]],
   ['textlayout_15',['TextLayout',['../classTextLayout.html',1,'']]],
   ['textpropertycomponent_16',['TextPropertyComponent',['../classTextPropertyComponent.html',1,'']]],
-  ['thiran_17',['Thiran',['../structdsp_1_1DelayLineInterpolationTypes_1_1Thiran.html',1,'dsp::DelayLineInterpolationTypes']]],
+  ['thiran_17',['Thiran',['../structjuce_1_1dsp_1_1DelayLineInterpolationTypes_1_1Thiran.html',1,'juce::dsp::DelayLineInterpolationTypes']]],
   ['thread_18',['Thread',['../classThread.html',1,'']]],
   ['threadedanalyticsdestination_19',['ThreadedAnalyticsDestination',['../classThreadedAnalyticsDestination.html',1,'']]],
   ['threadedwriter_20',['ThreadedWriter',['../classAudioFormatWriter_1_1ThreadedWriter.html',1,'AudioFormatWriter']]],
@@ -43,11 +43,13 @@ var searchData=
   ['tooltipclient_40',['TooltipClient',['../classTooltipClient.html',1,'']]],
   ['tooltipwindow_41',['TooltipWindow',['../classTooltipWindow.html',1,'']]],
   ['toplevelwindow_42',['TopLevelWindow',['../classTopLevelWindow.html',1,'']]],
-  ['trackinfo_43',['TrackInfo',['../structGrid_1_1TrackInfo.html',1,'Grid']]],
-  ['trackproperties_44',['TrackProperties',['../structAudioProcessor_1_1TrackProperties.html',1,'AudioProcessor']]],
-  ['tracktionmarketplacestatus_45',['TracktionMarketplaceStatus',['../classTracktionMarketplaceStatus.html',1,'']]],
-  ['treeview_46',['TreeView',['../classTreeView.html',1,'']]],
-  ['treeviewitem_47',['TreeViewItem',['../classTreeViewItem.html',1,'']]],
-  ['typeface_48',['Typeface',['../classTypeface.html',1,'']]],
-  ['typehandler_49',['TypeHandler',['../classComponentBuilder_1_1TypeHandler.html',1,'ComponentBuilder']]]
+  ['tovar_43',['ToVar',['../classToVar.html',1,'']]],
+  ['tovaroptions_44',['ToVarOptions',['../classToVarOptions.html',1,'']]],
+  ['trackinfo_45',['TrackInfo',['../structGrid_1_1TrackInfo.html',1,'Grid']]],
+  ['trackproperties_46',['TrackProperties',['../structAudioProcessor_1_1TrackProperties.html',1,'AudioProcessor']]],
+  ['tracktionmarketplacestatus_47',['TracktionMarketplaceStatus',['../classTracktionMarketplaceStatus.html',1,'']]],
+  ['treeview_48',['TreeView',['../classTreeView.html',1,'']]],
+  ['treeviewitem_49',['TreeViewItem',['../classTreeViewItem.html',1,'']]],
+  ['typeface_50',['Typeface',['../classTypeface.html',1,'']]],
+  ['typehandler_51',['TypeHandler',['../classComponentBuilder_1_1TypeHandler.html',1,'ComponentBuilder']]]
 ];
