@@ -2,7 +2,7 @@ var indexSectionsWithContent =
 {
   0: "_abcdefghijklmnopqrstuvwxyz~",
   1: "abcdefghijklmnopqrstuvwxz",
-  2: "acdgjpstuv",
+  2: "adjpstv",
   3: "cj",
   4: "_abcdefghijklmnopqrstuvwxyz~",
   5: "abcdefghijklmnopqrstuvwxyz",
@@ -12,7 +12,7 @@ var indexSectionsWithContent =
   9: "cgjs",
   10: "egjx",
   11: "abcdefghijklmnopstuvwxz",
-  12: "t"
+  12: "acfjmt"
 };
 
 var indexSectionNames =
