@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['cadetblue_0',['cadetblue',['../namespaceColours.html#a421e492047a35fd0fab10269c09e9ede',1,'Colours']]],
+  ['cadetblue_0',['cadetblue',['../namespacejuce_1_1Colours.html#ae15052778fd9a0fb42c74e8c9747d83c',1,'juce::Colours']]],
   ['cancelbutton_1',['cancelButton',['../classOnlineUnlockForm.html#ae1dc0ebc96b660f2a95b44ad23ed7ebb',1,'OnlineUnlockForm']]],
   ['canshowbadge_2',['canShowBadge',['../structPushNotifications_1_1Channel.html#aedaecd89fac8cabde95d26cc83b1fb92',1,'PushNotifications::Channel']]],
   ['categories_3',['categories',['../structPushNotifications_1_1Settings.html#a576f03626be05ad8122739d563a647fa',1,'PushNotifications::Settings']]],
@@ -14,19 +14,19 @@ var searchData=
   ['channelindex_11',['channelIndex',['../classAudioProcessorGraph_1_1NodeAndChannel.html#ab0ad32f6d0aa7608798726fc42eaa11f',1,'AudioProcessorGraph::NodeAndChannel']]],
   ['channellayout_12',['channelLayout',['../classAudioFormatWriter.html#abfd821aaba068593364888cb97c47a0b',1,'AudioFormatWriter']]],
   ['channels_13',['channels',['../structSpeakerMappings_1_1Mapping.html#a4bd54e10adf49ce9a185dae6b90d2218',1,'SpeakerMappings::Mapping']]],
-  ['chartreuse_14',['chartreuse',['../namespaceColours.html#ae1907f697e1d1b4830d21d0acec39272',1,'Colours']]],
-  ['chocolate_15',['chocolate',['../namespaceColours.html#a4ee3348e68486b4ee43e2f5361c939da',1,'Colours']]],
+  ['chartreuse_14',['chartreuse',['../namespacejuce_1_1Colours.html#ad9973a49bc33dde5d1a7a36106f15e62',1,'juce::Colours']]],
+  ['chocolate_15',['chocolate',['../namespacejuce_1_1Colours.html#a622c29dcb3238cbd8e535d88ae160a6f',1,'juce::Colours']]],
   ['choices_16',['choices',['../classAudioParameterChoice.html#afbeec68d8f56cf4cde23c1b615699b9f',1,'AudioParameterChoice::choices'],['../classChoicePropertyComponent.html#a9e1e134a3393008eaed61c31667b78fd',1,'ChoicePropertyComponent::choices']]],
   ['clip_17',['clip',['../structLowLevelGraphicsPostScriptRenderer_1_1SavedState.html#aa5fb5398ec25f56561c71a4792aa51fa',1,'LowLevelGraphicsPostScriptRenderer::SavedState']]],
   ['closessubpath_18',['closesSubPath',['../classPathFlatteningIterator.html#ac102af0a5ac3dfd026488c1efea1b8ab',1,'PathFlatteningIterator']]],
   ['code_19',['code',['../group__juce__audio__plugin__client-Unity.html#ga45a5b7c00a796a23f01673cef1dbe0a9',1,'juce_UnityPluginInterface.h']]],
-  ['coefficients_20',['coefficients',['../structdsp_1_1FIR_1_1Coefficients.html#a67c1af2e9f13855e4285f9c74b45c47c',1,'dsp::FIR::Coefficients::coefficients'],['../classdsp_1_1IIR_1_1Filter.html#a1486a25aaa47e90ae53837e18d4a772d',1,'dsp::IIR::Filter::coefficients'],['../classIIRCoefficients.html#a657c88078e4415353e6e987ce7a0f252',1,'IIRCoefficients::coefficients'],['../classIIRFilterBase.html#a6235eef3706c55ff3c6ba5c9c96dda22',1,'IIRFilterBase::coefficients'],['../classdsp_1_1FIR_1_1Filter.html#a4ff0c17a36a81521d4d56bf58f2dc318',1,'dsp::FIR::Filter::coefficients'],['../structdsp_1_1IIR_1_1Coefficients.html#a1bcb9d565ef02c914f2ad133cfb2b3a2',1,'dsp::IIR::Coefficients::coefficients']]],
+  ['coefficients_20',['coefficients',['../structjuce_1_1dsp_1_1FIR_1_1Coefficients.html#a9d176adc27924cf570aad8d8d26861cc',1,'juce::dsp::FIR::Coefficients::coefficients'],['../classjuce_1_1dsp_1_1IIR_1_1Filter.html#a48ed5d8b4883e92d7d857f054f5d0da5',1,'juce::dsp::IIR::Filter::coefficients'],['../classIIRCoefficients.html#a657c88078e4415353e6e987ce7a0f252',1,'IIRCoefficients::coefficients'],['../classIIRFilterBase.html#a6235eef3706c55ff3c6ba5c9c96dda22',1,'IIRFilterBase::coefficients'],['../classjuce_1_1dsp_1_1FIR_1_1Filter.html#a1277d195d003173c05ab8cdb26e70eb5',1,'juce::dsp::FIR::Filter::coefficients'],['../structjuce_1_1dsp_1_1IIR_1_1Coefficients.html#ae5251e258c433ebde459d8bd7ba1503c',1,'juce::dsp::IIR::Coefficients::coefficients']]],
   ['colour_21',['colour',['../structAudioProcessor_1_1TrackProperties.html#a7c59b53402cee38e8dd3f64c9e73dbd7',1,'AudioProcessor::TrackProperties::colour'],['../classFillType.html#a6eb1907c0b75fccfbf45ede3b3b490d9',1,'FillType::colour'],['../structDropShadow.html#ad8031be7a935da40c11f2ede9b9f2a44',1,'DropShadow::colour'],['../classAttributedString_1_1Attribute.html#a959a0822fe8fd8bf016efc5b9a8d71c1',1,'AttributedString::Attribute::colour'],['../classTextLayout_1_1Run.html#a0740a8644c5933b52c89dbe459bbaf3e',1,'TextLayout::Run::colour'],['../structPopupMenu_1_1Item.html#a500c07c17af9ed6a25abadca1d6879fd',1,'PopupMenu::Item::colour'],['../structCodeEditorComponent_1_1ColourScheme_1_1TokenType.html#ad64a0ec08892eba127e52ae798813780',1,'CodeEditorComponent::ColourScheme::TokenType::colour'],['../classOSCTypes.html#a8b3b5b795076174042ddb53500255846',1,'OSCTypes::colour']]],
   ['column_22',['column',['../classGridItem.html#a4009d56282795631940ec981f856255f',1,'GridItem']]],
   ['columngap_23',['columnGap',['../classGrid.html#a84078c5ef0dc6f6726db71caccb91506',1,'Grid']]],
   ['command_24',['command',['../structConsoleApplication_1_1Command.html#a6fc9a5507dc1835738d59d6de39a410b',1,'ConsoleApplication::Command']]],
   ['commandflags_25',['commandFlags',['../structApplicationCommandTarget_1_1InvocationInfo.html#a26fba7d10531e7613beb8e3ad0ffc239',1,'ApplicationCommandTarget::InvocationInfo']]],
-  ['commandid_26',['commandID',['../structApplicationCommandInfo.html#ac8265d08896874e8aad4f9bfee9e7e03',1,'ApplicationCommandInfo::commandID'],['../structApplicationCommandTarget_1_1InvocationInfo.html#a4416781aae4ac0dd75477ddd98cb31d4',1,'ApplicationCommandTarget::InvocationInfo::commandID']]],
+  ['commandid_26',['commandid',['../structApplicationCommandInfo.html#ac8265d08896874e8aad4f9bfee9e7e03',1,'ApplicationCommandInfo::commandID'],['../structApplicationCommandTarget_1_1InvocationInfo.html#a4416781aae4ac0dd75477ddd98cb31d4',1,'ApplicationCommandTarget::InvocationInfo::commandID']]],
   ['commandmanager_27',['commandManager',['../structPopupMenu_1_1Item.html#a12a2df0e3fa6e652c0e461ed065cc6c3',1,'PopupMenu::Item']]],
   ['commandoption_28',['commandOption',['../structConsoleApplication_1_1Command.html#a98c8e5736f46b734d2b84216484bde39',1,'ConsoleApplication::Command']]],
   ['commontoallusers_29',['commonToAllUsers',['../structPropertiesFile_1_1Options.html#a1b4a530664906ebeadce842431f6f681',1,'PropertiesFile::Options']]],
@@ -36,15 +36,15 @@ var searchData=
   ['constrainer_33',['constrainer',['../classComponentPeer.html#a75216f7f562c5bbf8b7758a1198d2744',1,'ComponentPeer']]],
   ['content_34',['content',['../structDialogWindow_1_1LaunchOptions.html#afb8d6fb02aec1a20e787de456556067a',1,'DialogWindow::LaunchOptions']]],
   ['contentlength_35',['contentLength',['../classURL_1_1DownloadTask.html#ab59855d4df9ae73ee720285f691b2971',1,'URL::DownloadTask']]],
-  ['controlpoints_36',['controlPoints',['../classRelativePointPath_1_1CubicTo.html#a6651df5d1d55b5b8cf5bfff380fe40ec',1,'RelativePointPath::CubicTo::controlPoints'],['../classRelativePointPath_1_1QuadraticTo.html#af52f78c292c1e148972929b2493c33fe',1,'RelativePointPath::QuadraticTo::controlPoints']]],
-  ['coral_37',['coral',['../namespaceColours.html#abf762b51e26b244b84390aa993b0f5cd',1,'Colours']]],
-  ['cornflowerblue_38',['cornflowerblue',['../namespaceColours.html#aacd9e0445427ebb8d956583b0798c643',1,'Colours']]],
-  ['cornsilk_39',['cornsilk',['../namespaceColours.html#abac76b22ce234e733b099fee363e1df3',1,'Colours']]],
+  ['controlpoints_36',['controlpoints',['../classRelativePointPath_1_1CubicTo.html#a6651df5d1d55b5b8cf5bfff380fe40ec',1,'RelativePointPath::CubicTo::controlPoints'],['../classRelativePointPath_1_1QuadraticTo.html#af52f78c292c1e148972929b2493c33fe',1,'RelativePointPath::QuadraticTo::controlPoints']]],
+  ['coral_37',['coral',['../namespacejuce_1_1Colours.html#a71d4d9db62cea342f456a591129c46db',1,'juce::Colours']]],
+  ['cornflowerblue_38',['cornflowerblue',['../namespacejuce_1_1Colours.html#a3e7368aaccdda2a7c2793e211f84b6d1',1,'juce::Colours']]],
+  ['cornsilk_39',['cornsilk',['../namespacejuce_1_1Colours.html#a767b765548474db748b7de42f5cc3bc6',1,'juce::Colours']]],
   ['countdown_40',['countdown',['../classSmoothedValueBase.html#a5428962e91e7745e9e4089bffe97852b',1,'SmoothedValueBase']]],
   ['creationtime_41',['creationTime',['../structDirectoryContentsList_1_1FileInfo.html#a903e1211fd14c33fe7af486e4e91b9b0',1,'DirectoryContentsList::FileInfo']]],
-  ['crimson_42',['crimson',['../namespaceColours.html#ad65a08b3f78f624abfc970c844b8d859',1,'Colours']]],
+  ['crimson_42',['crimson',['../namespacejuce_1_1Colours.html#aed6245af64f4fd1f22370f8f0c757efd',1,'juce::Colours']]],
   ['current_43',['current',['../structPushNotifications_1_1Notification_1_1Progress.html#a7a31c24734466a55144ac3b7de28d3a8',1,'PushNotifications::Notification::Progress']]],
-  ['currentbounds_44',['currentBounds',['../classFlexItem.html#aa8c1424c9e12c6b08a29c4767ec06704',1,'FlexItem::currentBounds'],['../classGridItem.html#a88d9b486b706c6c7b069aefa48adecd9',1,'GridItem::currentBounds']]],
+  ['currentbounds_44',['currentbounds',['../classFlexItem.html#aa8c1424c9e12c6b08a29c4767ec06704',1,'FlexItem::currentBounds'],['../classGridItem.html#a88d9b486b706c6c7b069aefa48adecd9',1,'GridItem::currentBounds']]],
   ['currentlyplayingnote_45',['currentlyPlayingNote',['../classMPESynthesiserVoice.html#aea34fcbdb3fa0961f73d5f9a1f34e255',1,'MPESynthesiserVoice']]],
   ['currentmodifiers_46',['currentModifiers',['../classModifierKeys.html#ae15cb452a97164e1b857086a1405942f',1,'ModifierKeys']]],
   ['currentsamplerate_47',['currentSampleRate',['../classMPESynthesiserVoice.html#a9310a73a44408ab65dfb9b875917c354',1,'MPESynthesiserVoice']]],
@@ -54,5 +54,5 @@ var searchData=
   ['customcomponent_51',['customComponent',['../structPopupMenu_1_1Item.html#a60e8c61225a127bf37c46144c03689f6',1,'PopupMenu::Item']]],
   ['customencoding_52',['customEncoding',['../structXmlElement_1_1TextFormat.html#ae7037150be1321862bb3cedb6642586a',1,'XmlElement::TextFormat']]],
   ['customheader_53',['customHeader',['../structXmlElement_1_1TextFormat.html#a9b77aa7cdec984b10decc585ca19ba6f',1,'XmlElement::TextFormat']]],
-  ['cyan_54',['cyan',['../namespaceColours.html#a3e14715b6e4b1864493f7a325c3b6ce2',1,'Colours']]]
+  ['cyan_54',['cyan',['../namespacejuce_1_1Colours.html#aae679abcbd91e4e965324039f46ae65c',1,'juce::Colours']]]
 ];
