@@ -1,31 +1,31 @@
 var searchData=
 [
   ['damping_0',['damping',['../structReverb_1_1Parameters.html#afbbd3f114c878f0a864205aa66d47f6f',1,'Reverb::Parameters']]],
-  ['darkblue_1',['darkblue',['../namespaceColours.html#a3966ee221878df55b749eaecbfa44ed8',1,'Colours']]],
-  ['darkcyan_2',['darkcyan',['../namespaceColours.html#a75a5f4fe2cd36c4aa928e980712842d9',1,'Colours']]],
-  ['darkgoldenrod_3',['darkgoldenrod',['../namespaceColours.html#a28dba2b7be6655790a6f041e845f2dbc',1,'Colours']]],
-  ['darkgreen_4',['darkgreen',['../namespaceColours.html#ac9acde56d3a795eac6b475d710705c0c',1,'Colours']]],
-  ['darkgrey_5',['darkgrey',['../namespaceColours.html#a1da556a9a39d6712b921c41ce9198456',1,'Colours']]],
-  ['darkkhaki_6',['darkkhaki',['../namespaceColours.html#a1367d710da3c1eb0f81000c98b3895e5',1,'Colours']]],
-  ['darkmagenta_7',['darkmagenta',['../namespaceColours.html#ae80a5cbd40c9dae08acb82d7bd1f9b75',1,'Colours']]],
-  ['darkolivegreen_8',['darkolivegreen',['../namespaceColours.html#a506d0307bb1742117f1e7a04953a2888',1,'Colours']]],
-  ['darkorange_9',['darkorange',['../namespaceColours.html#a4f7d5745f92ecf0f2b1a9b593b80bcf8',1,'Colours']]],
-  ['darkorchid_10',['darkorchid',['../namespaceColours.html#aa737976f915868ebb74e5f6d78d074a5',1,'Colours']]],
-  ['darkred_11',['darkred',['../namespaceColours.html#a5b6edc49a88186b8cf3d66332685100e',1,'Colours']]],
-  ['darksalmon_12',['darksalmon',['../namespaceColours.html#a7de96e423e9d8d73e9dcc878e09e86a9',1,'Colours']]],
-  ['darkseagreen_13',['darkseagreen',['../namespaceColours.html#af5aab22d4f3382764b9ce88375547203',1,'Colours']]],
-  ['darkslateblue_14',['darkslateblue',['../namespaceColours.html#a3d354ef190a79533a76067cd633eabcc',1,'Colours']]],
-  ['darkslategrey_15',['darkslategrey',['../namespaceColours.html#a0afc1a2cbfb91eb31d3ccef55108a3ad',1,'Colours']]],
-  ['darkturquoise_16',['darkturquoise',['../namespaceColours.html#a20b184f9a21208993a7a59f3f2dde4b4',1,'Colours']]],
-  ['darkviolet_17',['darkviolet',['../namespaceColours.html#aa44e514b77456076aa1f6961c7fecca4',1,'Colours']]],
+  ['darkblue_1',['darkblue',['../namespacejuce_1_1Colours.html#a70ff99f898d1b39e7f35bde55b1eeaf9',1,'juce::Colours']]],
+  ['darkcyan_2',['darkcyan',['../namespacejuce_1_1Colours.html#a6f3a6c4a60131b46bf40cc948640daf5',1,'juce::Colours']]],
+  ['darkgoldenrod_3',['darkgoldenrod',['../namespacejuce_1_1Colours.html#af1985b99db7b117a874f3eed4d064175',1,'juce::Colours']]],
+  ['darkgreen_4',['darkgreen',['../namespacejuce_1_1Colours.html#a2b8f56b046fc11c691ec8425498890cf',1,'juce::Colours']]],
+  ['darkgrey_5',['darkgrey',['../namespacejuce_1_1Colours.html#a69ec696dd3916625ddb07fb16c72bc8a',1,'juce::Colours']]],
+  ['darkkhaki_6',['darkkhaki',['../namespacejuce_1_1Colours.html#ac5a720eb2970239e391b0121b8a07e4d',1,'juce::Colours']]],
+  ['darkmagenta_7',['darkmagenta',['../namespacejuce_1_1Colours.html#a44651777edd911536c7de3643237c5b4',1,'juce::Colours']]],
+  ['darkolivegreen_8',['darkolivegreen',['../namespacejuce_1_1Colours.html#aa240694027131f2e83773a6970d5d449',1,'juce::Colours']]],
+  ['darkorange_9',['darkorange',['../namespacejuce_1_1Colours.html#a94a4cfcfe1decef801dfa96803ceb824',1,'juce::Colours']]],
+  ['darkorchid_10',['darkorchid',['../namespacejuce_1_1Colours.html#a8b61d28a09bca86a5d0103936743946e',1,'juce::Colours']]],
+  ['darkred_11',['darkred',['../namespacejuce_1_1Colours.html#ac5011c8d0047f9b1b360dac4c101353b',1,'juce::Colours']]],
+  ['darksalmon_12',['darksalmon',['../namespacejuce_1_1Colours.html#a5a7f94e4d9416c9e6b5bfebc4cd0ff86',1,'juce::Colours']]],
+  ['darkseagreen_13',['darkseagreen',['../namespacejuce_1_1Colours.html#a1ea408ff0f65c79a1641edcbbf00310a',1,'juce::Colours']]],
+  ['darkslateblue_14',['darkslateblue',['../namespacejuce_1_1Colours.html#aa14a2f42891800c7c2db697cf1f94301',1,'juce::Colours']]],
+  ['darkslategrey_15',['darkslategrey',['../namespacejuce_1_1Colours.html#a2b5effa5558667110e3677651ff70c33',1,'juce::Colours']]],
+  ['darkturquoise_16',['darkturquoise',['../namespacejuce_1_1Colours.html#a23eef4d2e31deb12163d19c19f391c0a',1,'juce::Colours']]],
+  ['darkviolet_17',['darkviolet',['../namespacejuce_1_1Colours.html#ae671b948f6a652bd19419b93cb124fe5',1,'juce::Colours']]],
   ['dashlengths_18',['dashLengths',['../classDrawableShape.html#a5c20c34a8e2f8de83cd9c83c3abd830d',1,'DrawableShape']]],
   ['data_19',['data',['../structMidiMessageMetadata.html#adb725357cb9b28b941c9dc9bcbe920b0',1,'MidiMessageMetadata::data'],['../classMidiBuffer.html#a7982121d5b53cc1dd6371898d6472de7',1,'MidiBuffer::data'],['../classImage_1_1BitmapData.html#a20783df25b604990685fe8cbb0f1cf91',1,'Image::BitmapData::data']]],
   ['datachunkstart_20',['dataChunkStart',['../classMemoryMappedAudioFormatReader.html#a50ccc5aaa756180f865ad1b6ff43bf0d',1,'MemoryMappedAudioFormatReader']]],
   ['datalength_21',['dataLength',['../classMemoryMappedAudioFormatReader.html#ac19c1cd6d4aff52e7820ec40e1e4d271',1,'MemoryMappedAudioFormatReader']]],
   ['datareleaser_22',['dataReleaser',['../classImage_1_1BitmapData.html#a486bc70dddebcb42d5e5dbabfda371e4',1,'Image::BitmapData']]],
   ['decay_23',['decay',['../structADSR_1_1Parameters.html#a23e64783cbd03a51f01133edfb38321d',1,'ADSR::Parameters']]],
-  ['deeppink_24',['deeppink',['../namespaceColours.html#ad9d4c6a592d7485141177811acc80632',1,'Colours']]],
-  ['deepskyblue_25',['deepskyblue',['../namespaceColours.html#a81db0928928689b736df29ce6bf2fe75',1,'Colours']]],
+  ['deeppink_24',['deeppink',['../namespacejuce_1_1Colours.html#aa4b40e69e5477b4e2e75258eae596986',1,'juce::Colours']]],
+  ['deepskyblue_25',['deepskyblue',['../namespacejuce_1_1Colours.html#a7f07ce832771fdb24849881fa91f480e',1,'juce::Colours']]],
   ['defaultcharacter_26',['defaultCharacter',['../classCustomTypeface.html#a253a2ab299747b043f623ddbdd354e15',1,'CustomTypeface']]],
   ['defaultkeypresses_27',['defaultKeypresses',['../structApplicationCommandInfo.html#acae1903bdfd8214162adb8326d1ee9da',1,'ApplicationCommandInfo']]],
   ['defaultlayout_28',['defaultLayout',['../structAudioProcessor_1_1BusProperties.html#a72866039f0acaecb38d84a43f74fe95d',1,'AudioProcessor::BusProperties']]],
@@ -36,7 +36,7 @@ var searchData=
   ['defaulttilty_33',['defaultTiltY',['../classMouseInputSource.html#ac88da9d624568981faba83e83a5a30a2',1,'MouseInputSource']]],
   ['defaulttoleranceformeasurement_34',['defaultToleranceForMeasurement',['../classPath.html#a8e27579a740ab71d223ea7398a995fbb',1,'Path']]],
   ['defaulttolerancefortesting_35',['defaultToleranceForTesting',['../classPath.html#aa23f987b8292143c3c9a6d9b0a131c3b',1,'Path']]],
-  ['delayedpath_36',['delayedPath',['../structdsp_1_1FilterDesign_1_1IIRPolyphaseAllpassStructure.html#a5d1ee8cddc6a38760b4d2a36cc371e34',1,'dsp::FilterDesign::IIRPolyphaseAllpassStructure']]],
+  ['delayedpath_36',['delayedPath',['../structjuce_1_1dsp_1_1FilterDesign_1_1IIRPolyphaseAllpassStructure.html#abe15fe728acebf123586221fb50c9258',1,'juce::dsp::FilterDesign::IIRPolyphaseAllpassStructure']]],
   ['deletekey_37',['deleteKey',['../classKeyPress.html#ae568c9aba033acf0c24390f24304b9e5',1,'KeyPress']]],
   ['deltax_38',['deltaX',['../structMouseWheelDetails.html#a09f65902f9a85a4c035cfdd350195666',1,'MouseWheelDetails']]],
   ['deltay_39',['deltaY',['../structMouseWheelDetails.html#af2fbbe8a59ef8e84f7bbe5a2cd441fbe',1,'MouseWheelDetails']]],
@@ -49,14 +49,14 @@ var searchData=
   ['desiredthreadpriority_46',['desiredThreadPriority',['../structThreadPoolOptions.html#ae4dc6a44e03a4596d73f9a5120322564',1,'ThreadPoolOptions']]],
   ['destination_47',['destination',['../structAudioProcessorGraph_1_1Connection.html#a056525d39e5c9aa8b07ddd64183de544',1,'AudioProcessorGraph::Connection']]],
   ['destructive_48',['destructive',['../structPushNotifications_1_1Notification_1_1Action.html#ab56bfdc62b16ba7c7cb1775af96eaefa',1,'PushNotifications::Notification::Action']]],
-  ['devicemanager_49',['deviceManager',['../classStandalonePluginHolder.html#a6fb1eb9dcabd5f5d6e2c52a44296e017',1,'StandalonePluginHolder::deviceManager'],['../classAudioAppComponent.html#a546cdb47015129a529ff8f4849352930',1,'AudioAppComponent::deviceManager'],['../classAudioDeviceSelectorComponent.html#a1d55ccd0985a42f37b5683f609b65386',1,'AudioDeviceSelectorComponent::deviceManager']]],
+  ['devicemanager_49',['devicemanager',['../classStandalonePluginHolder.html#a6fb1eb9dcabd5f5d6e2c52a44296e017',1,'StandalonePluginHolder::deviceManager'],['../classAudioAppComponent.html#a546cdb47015129a529ff8f4849352930',1,'AudioAppComponent::deviceManager'],['../classAudioDeviceSelectorComponent.html#a1d55ccd0985a42f37b5683f609b65386',1,'AudioDeviceSelectorComponent::deviceManager']]],
   ['dialogbackgroundcolour_50',['dialogBackgroundColour',['../structDialogWindow_1_1LaunchOptions.html#a301462bfb1591667490f392113225083',1,'DialogWindow::LaunchOptions']]],
   ['dialogtitle_51',['dialogTitle',['../structDialogWindow_1_1LaunchOptions.html#ac9b19e68e10b4d64b2bb9c37b460afbf',1,'DialogWindow::LaunchOptions']]],
-  ['dimgrey_52',['dimgrey',['../namespaceColours.html#a2f56cf8882ce1acc648a8382caa8c670',1,'Colours']]],
+  ['dimgrey_52',['dimgrey',['../namespacejuce_1_1Colours.html#a53f4cad3620ca8cc1964a87d89d80f94',1,'juce::Colours']]],
   ['directorycontentslist_53',['directoryContentsList',['../classDirectoryContentsDisplayComponent.html#ac1eef63c05c6a3dc42de447ace64a3dd',1,'DirectoryContentsDisplayComponent']]],
-  ['directpath_54',['directPath',['../structdsp_1_1FilterDesign_1_1IIRPolyphaseAllpassStructure.html#a784606872384b743910554f1e41b2296',1,'dsp::FilterDesign::IIRPolyphaseAllpassStructure']]],
+  ['directpath_54',['directPath',['../structjuce_1_1dsp_1_1FilterDesign_1_1IIRPolyphaseAllpassStructure.html#a9742ace24ff00e0727ea16e192b5ff1a',1,'juce::dsp::FilterDesign::IIRPolyphaseAllpassStructure']]],
   ['displays_55',['displays',['../classDisplays.html#a06cb25ef3be2ed477d2081e5a16369e2',1,'Displays']]],
-  ['dodgerblue_56',['dodgerblue',['../namespaceColours.html#a3d34bebff250100f2a332d01531f948d',1,'Colours']]],
+  ['dodgerblue_56',['dodgerblue',['../namespacejuce_1_1Colours.html#ac98c8b85b3fb170393e66dc5b06b658e',1,'juce::Colours']]],
   ['donotsave_57',['doNotSave',['../structPropertiesFile_1_1Options.html#a28680056e89b7947afe4de44c4ac26c9',1,'PropertiesFile::Options']]],
   ['downkey_58',['downKey',['../classKeyPress.html#aeb9a20dd50b39f66d7d778d31b6b5f88',1,'KeyPress']]],
   ['downloaded_59',['downloaded',['../classURL_1_1DownloadTask.html#a4754c8c08c94390dac2ffdcf76badd86',1,'URL::DownloadTask']]],
